<template>
  <section>
    <el-form :inline="true" ref="formRef" :model="form" class="demo-form-inline" size="default" label-position="right"
      label-width="200px" :rules="rules">
      <el-row>
        <el-col :span="12">
          <el-form-item label="银行账户类型" prop="cardType">
            <el-select v-model="form.cardType" placeholder="" clearable style="width: 100%;">
              <el-option value="0" label="对公"></el-option>
              <el-option value="1" label="对私"></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="银行账户名称" prop="cardName">
            <el-input v-model="form.cardName" placeholder="" clearable />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="银行卡号" prop="cardNo">
            <el-input v-model="form.cardNo" placeholder="" clearable />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="银行开户地区" prop="areaArr">
            <el-cascader v-model="form.areaArr" :props="customProps" :options="form.areaArroptions" placeholder="请选择省市"
              style="width: 100%;" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="银行名称" prop="bankCode">
            <el-select v-model="form.bankCode" placeholder="请选择银行名称" filterable clearable style="width: 100%;">
              <el-option v-for="(item, index) in form.bankCodeList" :value="String(item.bankCode)"
                :label="item.bankName"></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="支行名称" prop="branchCode">
            <el-select v-model="form.branchCode" placeholder="请输入支行名称" filterable :filter-method="filterBranchMethod"
              clearable style="width: 100%;" @change="branchCodeChange" :no-data-text="nodataTxt"
              :no-match-text="nomatchTxt">
              <el-option v-for="(item, index) in form.branchCodeList" :value="String(item.branchCode)"
                :label="item.branchName"></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="业务类型" prop="cashTypeT">
            <el-checkbox-group v-model="form.cashTypeT">
              <el-checkbox v-for="item in cashTypeArr" :key="item.value" :label="item.value"
                :disabled="form.cashType.indexOf(item.value) > -1">{{
                  item.label
                }}</el-checkbox>
            </el-checkbox-group>
          </el-form-item>
        </el-col>

        <el-col :span="24">
          <el-form-item>
            <el-button type="primary" style="margin:50px auto;" @click="submitForm(formRef)">绑定银行卡</el-button>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
  </section>
</template>
<script lang="ts" setup>
import { onMounted, reactive, ref, nextTick } from 'vue'
import type { FormInstance } from 'element-plus'
import { ConfigApi } from '/@/api/api'
//定义变量
const formRef = ref<FormInstance>()
const flag = ref(false)//判断是从我的钱包过来才加载查询账号接口，默认false
const nodataTxt = ref('请手动输入支行名称，输入时如自动出现正确名称可选择')
const nomatchTxt = ref('请手动输入支行名称，输入时如自动出现正确名称可选择')
//必填校验
const rules = reactive({
  cardType: [{ required: true, trigger: 'blur', message: '必填项' }],
  cardName: [{ required: true, trigger: 'blur', message: '必填项' }],
  cardNo: [{ required: true, trigger: 'blur', message: '必填项' }],
  areaArr: [{ required: true, trigger: 'blur', message: '必填项' }],
  bankCode: [{ required: true, trigger: 'blur', message: '必填项' }],
  branchCode: [{ required: true, trigger: 'blur', message: '必填项' }],
  cashTypeT: [{ required: true, trigger: 'blur', message: '必填项' }],
})
//表单响应数据
const form = ref({
  cardType: '',
  cardName: '',
  cardNo: '',
  areaArr: [],
  provId: '',
  areaId: '',
  bankCode: '',
  branchCode: '',
  areaArroptions: [],
  bankCodeList: [],
  branchCodeList: [],
  branchName: '',
  cashType: '',
  cashTypeT: [],
})
// const cashTypeArr = ref([{ label: '当日到账', value: 'D0' }, { label: '明日到账', value: 'D1' }])
const cashTypeArr = ref([{ label: '明日到账', value: 'D1' }])
//省市区默认
interface CascaderProps {
  multiple?: boolean
  checkStrictly?: boolean
  emitPath?: boolean
  lazy?: boolean
  value?: string
  label?: string
  children?: string
}
const customProps: CascaderProps = reactive({
  value: "regionId", // 自定义当前数组的键名 - value
  label: "regionName", // 自定义当前数组的键名 - label
  children: "child", // 自定义当前数组的键名 - children
})
// 定义子组件向父组件传值/事件
const emit = defineEmits(['stepInfo']);
//提交按钮
const submitForm = (formEl: FormInstance | undefined) => {
  console.log(form.value)
  // return
  if (!formEl) return
  formEl.validate((valid) => {
    if (valid) {
      if (form.value.areaArr.length) {
        let arr = form.value.areaArr
        form.value.provId = String(arr[0])
        form.value.areaId = String(arr[1])
      }
      console.log('submit!')
      let data = JSON.parse(JSON.stringify(form.value))
      delete data.areaArroptions
      delete data.bankCodeList
      delete data.branchCodeList
      delete data.areaArr
      let obj = {
        cardType: data.cardType,
        cardName: data.cardName,
        cardNo: data.cardNo,
        provId: data.provId,
        areaId: data.areaId,
        bankCode: data.bankCode,
        branchCode: data.branchCode,
        branchName: data.branchName,
        cashType: String(data.cashTypeT)
      }
      ConfigApi().saveAccountBusiApi(obj).then(res => {
        console.log('res3', res)
        if (res.code == 200) {
          if (flag.value) {
            emit('stepInfo', 3)
          } else {
            emit('stepInfo', 2)//当前是第二步
          }
        }
      })
    } else {
      console.log('error submit!')
      return false
    }
  })
}
//获取企业钱包账户信息
const getWalletAccount = () => {
  ConfigApi().getWalletAccountaApi().then((res) => {
    console.log(res)
    form.value = res.data
    if (res.data.cashType) {
      form.value.cashTypeT = [res.data.cashType]
    } else {
      form.value.cashTypeT = ['D1']
    }
    nextTick(async () => {
      // console.log('form.value.branchCode', form.value.branchCode)
      // console.log('form.value.branchCodeList', form.value.branchCodeList)
      await filterBranchMethod(form.value.branchName)
      await branchCodeChange(form.value.branchCode)
    })
  })
}
//获取银行列表
const findBanks = () => {
  let data = {}
  ConfigApi().findBanksApi(data).then(res => {
    console.log('res11', res)
    form.value.bankCodeList = res.data
  })
}
//根据银行名称获取支行名称
const branchCodeChange = (val) => {
  console.log('val2', val)
  console.log('form.branchCodeList', form.value.branchCodeList)
  if (val && form.value.branchCodeList) {
    form.value.branchCodeList.find(item => {
      if (item.branchCode == val) {
        form.value.branchName = item.branchName
        return item
      }
    })
  }
}
//输入支行名称
const filterBranchMethod = (val) => {
  console.log(val)
  if (val) {
    let data = {
      bankCode: form.value.bankCode,
      branchName: val
    }
    ConfigApi().findBanksApi(data).then(res => {
      console.log(res)
      form.value.branchCodeList = res.data
    })
  }
}
// //获取省市区
const getCityList = () => {
  ConfigApi().getCityListApi().then(res => {
    // debugger
    let data = res.data.map(item => {
      console.log(item)
      if (item.child) {
        item.child.forEach(its => {
          console.log(its)
          if (its.regionType == 2) {
            return its.child = []
          }
        })
        return item;
      }
    })
    form.value.areaArroptions = data
    form.value.areaArr = [Number(form.value.provId), Number(form.value.areaId)]

  })
}
//父传递给子
const openDialog = (flagT) => {
  console.log('flagT', flagT)
  flag.value = flagT
  if (flag.value) {
    getWalletAccount()
  }
}
const cashTypeChange = (val) => {
  console.log(val)
}
onMounted(() => {
  findBanks()
  getCityList()//获取省市
})
// 暴露变量
defineExpose({
  openDialog,
});
</script>
<style lang="scss" scoped>
.el-form--inline .el-form-item {
  display: flex;
}

.tipscolor {
  color: rgb(255, 170, 0);
  line-height: 30px;
}
</style>